iterationtools.iterate_namesakes_from_component
===============================================

.. autofunction:: abjad.tools.iterationtools.iterate_namesakes_from_component.iterate_namesakes_from_component
   :noindex:
